@@ -59,8 +59,10 @@ import com.openexchange.group.GroupService;
 import com.openexchange.groupware.calendar.AppointmentSqlFactoryService;
 import com.openexchange.groupware.calendar.CalendarCollectionService;
 import com.openexchange.groupware.settings.PreferencesItemService;
+import com.openexchange.html.HtmlService;
 import com.openexchange.i18n.I18nService;
 import com.openexchange.osgi.RegistryCustomizer;
+import com.openexchange.resource.ResourceService;
 import com.openexchange.templating.TemplateService;
 import com.openexchange.user.UserService;
 
@@ -88,6 +90,15 @@ public class CalendarPrintingActivator extends AbstractSessionServletActivator {
         registerService(PreferencesItemService.class, new CalendarPrintingEnabled());
     }
 
+    @Override
+    protected void stopBundle() throws Exception {
+        try {
+            super.stopBundle();
+        } finally {
+            CPServlet.setServiceLookup(null);
+        }
+    }
+
     private void register() {
         final TemplateService templates = getService(TemplateService.class);
         final AppointmentSqlFactoryService appointmentSqlFactory = getService(AppointmentSqlFactoryService.class);
@@ -97,15 +108,13 @@ public class CalendarPrintingActivator extends AbstractSessionServletActivator {
             return;
         }
 
-        CPServlet.setTemplateService(templates);
-        CPServlet.setAppointmentSqlFactoryService(appointmentSqlFactory);
-        CPServlet.setCalendarTools(collectionService);
+        CPServlet.setServiceLookup(this);
 
         registerSessionServlet(getService(DispatcherPrefixService.class).getPrefix()+"printCalendar", new CPServlet());
     }
 
     @Override
     protected Class<?>[] getAdditionalNeededServices() {
-        return new Class<?>[] { TemplateService.class, AppointmentSqlFactoryService.class, CalendarCollectionService.class, DispatcherPrefixService.class };
+        return new Class<?>[] { TemplateService.class, AppointmentSqlFactoryService.class, CalendarCollectionService.class, DispatcherPrefixService.class, HtmlService.class, UserService.class, ResourceService.class };
     }
 }
